%define major           1
%define pcscspy_major   0
%define libname         %mklibname pcsclite %{major}
%define pcscspy_libname %mklibname pcscspy %{pcscspy_major}
%define develname       %mklibname pcsclite -d

Summary:	M.U.S.C.L.E. PC/SC Framework for Linux
Name:		pcsc-lite
Version:	2.3.1
Release:	%mkrel 2
License:	BSD-3-Clause AND BSD-2-Clause AND GPL-3.0-or-later
Group:		System/Servers
URL:		https://pcsclite.apdu.fr/
Source0:	https://pcsclite.apdu.fr/files/%{name}-%{version}.tar.xz
Source1:	https://pcsclite.apdu.fr/files/%{name}-%{version}.tar.xz.asc

BuildRequires:	meson
BuildRequires:	doxygen
BuildRequires:	flex
BuildRequires:	pkgconfig(polkit-agent-1)
BuildRequires:	pkgconfig(udev)

Requires(post):	rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1
Requires:	%{libname} = %{version}

# This is bundled in upstream without simple way to remove
Provides:	bundled(simclist) = 1.6

%description
The purpose of PC/SC Lite is to provide a Windows(R) SCard interface
in a very small form factor for communicating to smartcards and
readers.  PC/SC Lite uses the same winscard API as used under
Windows(R).  This package includes the PC/SC Lite daemon, a resource
manager that coordinates communications with smart card readers and
smart cards that are connected to the system, as well as other command
line tools.

%package -n	%{libname}
Summary:	Muscle PCSC Framework for Linux libraries
Group:		System/Libraries
Provides:	libpcsclite%{major} = %{version}-%{release}

%description -n	%{libname}
The purpose of PCSC Lite is to provide a Windows(R) SCard interface in a
very small form factor for communicating to smartcards and readers.
PCSC Lite uses the same winscard api as used under Windows(R).

The %{name}-devel package contains the header files and libraries
needed for compiling PCSC Lite programs. If you want to develop PCSC Lite-aware
programs, you'll need to install this package.

This package was tested to work with A.E.T. Europe B.V. SafeSign. This
package is supported by A.E.T. Europe B.V. when used in combination with
SafeSign.

%package -n	pcsc-spy
Summary:	PCSC API spy
Group:		System/Libraries

Requires:	python3
Requires:	pcsc-lite
Requires:	%{pcscspy_libname} = %{version}

%description -n	pcsc-spy
The purpose of pcsc-spy is to spy all the calls between the PC/SC client
and the PC/SC library.

%package -n	%{pcscspy_libname}
Summary:	PCSC Smart Card Library
Group:		System/Libraries

%description -n	%{pcscspy_libname}
Supporting library for the PC/SC spy tool.

%package -n	%{develname}
Summary:	Muscle PCSC Framework for Linux development files
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Requires:	%{pcscspy_libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	libpcsclite-devel = %{version}-%{release}

%description -n	%{develname}
The purpose of PCSC Lite is to provide a Windows(R) SCard interface in a
very small form factor for communicating to smartcards and readers.
PCSC Lite uses the same winscard api as used under Windows(R).

The %{name}-devel package contains the header files and libraries
needed for compiling PCSC Lite programs. If you want to develop PCSC Lite-aware
programs, you'll need to install this package.

This package was tested to work with A.E.T. Europe B.V. SafeSign. This
package is supported by A.E.T. Europe B.V. when used in combination with
SafeSign.

%package	doc
Summary:	PC/SC Lite developer documentation
Group:		Development/Other
BuildArch:	noarch

%description	doc
PC/SC Lite developer documentation.


%prep
%autosetup -p1

%build
%meson \
    -Dlibsystemd=true \
    -Dsystemdunit=system \
    -Dserial=true \
    -Dusbdropdir=%{_libdir}/pcsc/drivers \
    -Dpolkit=true

%meson_build
%meson_build doc

%install
%meson_install

# Create empty directories
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/reader.conf.d
mkdir -p $RPM_BUILD_ROOT%{_libdir}/pcsc/drivers

rm %{buildroot}%{_libdir}/libpcsclite.a

%post
%_post_service pcscd
# If install, test if pcscd socket is enabled.
# If enabled, then attempt to start it. This will silently fail
# in chroots or other environments where services aren't expected
# to be started.

if [ $1 -eq 1 ] ; then
	if systemctl -q is-enabled pcscd.socket > /dev/null 2>&1 ; then
		systemctl start pcscd.socket > /dev/null 2>&1 || :
	fi
fi

%preun
%_preun_service pcscd

%postun
%systemd_postun_with_restart pcscd.socket pcscd.service

%files
%doc AUTHORS ChangeLog HELP README SECURITY
%doc doc/README.polkit
%doc src/spy/setup_spy.sh
%dir %{_sysconfdir}/reader.conf.d/
%dir %{_libdir}/pcsc/drivers/
%{_sysconfdir}/default/pcscd
%{_datadir}/polkit-1/actions/org.debian.pcsc-lite.policy
%{_unitdir}/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_sbindir}/*
%{_metainfodir}/fr.apdu.pcsclite.metainfo.xml

%files -n %{libname}
%license COPYING
%{_libdir}/libpcsc*.so.%{major}{,.*}

%files -n pcsc-spy
%{_bindir}/pcsc-spy
%{_mandir}/man1/pcsc-spy.1.*

%files -n %{pcscspy_libname}
%{_libdir}/libpcscspy.so.%{pcscspy_major}{,.*}

%files -n %{develname}
%doc ChangeLog
%{_libdir}/pkgconfig/libpcsclite.pc
%{_includedir}/*
%{_libdir}/*.so

%files doc
%doc %{_vpath_builddir}/doc/api/ doc/example/pcsc_demo.c


%changelog
* Tue Jul 01 2025 umeabot <umeabot> 2.3.1-2.mga10
+ Revision: 2234707
- Mageia 10 Mass Rebuild

* Sat Jan 25 2025 daviddavid <daviddavid> 2.3.1-1.mga10
+ Revision: 2142098
- new version: 2.3.1

* Mon Aug 05 2024 daviddavid <daviddavid> 2.3.0-1.mga10
+ Revision: 2083641
- new version: 2.3.0
- switch to meson build system
- use our systemd post/preun macros

* Tue Apr 09 2024 danf <danf> 2.0.3-1.mga10
+ Revision: 2056084
- 2.0.3

* Wed Feb 14 2024 ns80 <ns80> 1.9.9-2.mga10
+ Revision: 2041091
- fix access to USB smartcard reader from within a flatpak sandbox (mga#32830)

* Tue Sep 27 2022 luigiwalser <luigiwalser> 1.9.9-1.mga9
+ Revision: 1892570
- 1.9.9

* Thu Jun 16 2022 luigiwalser <luigiwalser> 1.9.8-1.mga9
+ Revision: 1864623
- 1.9.8

* Wed May 18 2022 luigiwalser <luigiwalser> 1.9.7-1.mga9
+ Revision: 1858705
- 1.9.7
- update patch1 from fedora

* Tue Mar 29 2022 umeabot <umeabot> 1.9.5-2.mga9
+ Revision: 1832146
- Mageia 9 Mass Rebuild

* Thu Dec 09 2021 luigiwalser <luigiwalser> 1.9.5-1.mga9
+ Revision: 1761260
- 1.9.5

* Sat Oct 30 2021 luigiwalser <luigiwalser> 1.9.4-1.mga9
+ Revision: 1753360
- 1.9.4

* Sun Aug 08 2021 luigiwalser <luigiwalser> 1.9.3-1.mga9
+ Revision: 1740268
- 1.9.3

* Fri Aug 06 2021 luigiwalser <luigiwalser> 1.9.2-1.mga9
+ Revision: 1739931
- 1.9.2

* Tue Aug 03 2021 luigiwalser <luigiwalser> 1.9.1-1.mga9
+ Revision: 1738741
- 1.9.1
- update URLs
- add patch from fedora to increase maximum readers contexts

* Tue Aug 11 2020 sander85 <sander85> 1.9.0-1.mga8
+ Revision: 1613230
- New version: 1.9.0

* Wed Feb 19 2020 umeabot <umeabot> 1.8.26-2.mga8
+ Revision: 1543004
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Jan 08 2020 sander85 <sander85> 1.8.26-1.mga8
+ Revision: 1477322
- New version: 1.8.26

* Thu May 23 2019 sander85 <sander85> 1.8.24-2.mga7
+ Revision: 1398932
- Switch to %%systemd_* macros for socket handling (thanks to Fedora!)

* Wed Nov 14 2018 sander85 <sander85> 1.8.24-1.mga7
+ Revision: 1329925
- New version: 1.8.24

* Sun Sep 23 2018 umeabot <umeabot> 1.8.23-2.mga7
+ Revision: 1300143
- Mageia 7 Mass Rebuild

* Sat Feb 24 2018 sander85 <sander85> 1.8.23-1.mga7
+ Revision: 1204806
- New version: 1.8.23

* Mon Jul 17 2017 sander85 <sander85> 1.8.22-1.mga7
+ Revision: 1124129
- New version: 1.8.22

* Thu Jan 05 2017 sander85 <sander85> 1.8.20-1.mga6
+ Revision: 1080198
- New version: 1.8.20

* Sat Apr 30 2016 sander85 <sander85> 1.8.16-1.mga6
+ Revision: 1008334
- New version: 1.8.16

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.8.15-1.mga6
+ Revision: 918830
- 1.8.15

* Tue Oct 27 2015 danf <danf> 1.8.14-2.mga6
+ Revision: 895719
- Fix build on new rpm by listing extra doc file

* Wed Aug 05 2015 sander85 <sander85> 1.8.14-1.mga6
+ Revision: 861260
- New version: 1.8.14

* Fri Jun 26 2015 doktor5000 <doktor5000> 1.8.13-1.mga6
+ Revision: 844496
- new version 1.8.13
- adjusted URL to point to pcsc-lite project subpage
- enabled polkit support

* Wed Oct 15 2014 umeabot <umeabot> 1.8.11-4.mga5
+ Revision: 750379
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.8.11-3.mga5
+ Revision: 727546
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.8.11-2.mga5
+ Revision: 683374
- Mageia 5 Mass Rebuild
+ sander85 <sander85>
- Convert to %%autosetup

* Sat Jun 21 2014 sander85 <sander85> 1.8.11-1.mga5
+ Revision: 638310
- New version: 1.8.11

* Tue Feb 04 2014 sander85 <sander85> 1.8.10-1.mga5
+ Revision: 580578
- New version: 1.8.10

* Sat Oct 19 2013 umeabot <umeabot> 1.8.8-2.mga4
+ Revision: 525748
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 sander85 <sander85> 1.8.8-1.mga4
+ Revision: 434450
- New version: 1.8.8

* Sat Feb 02 2013 sander85 <sander85> 1.8.7-3.mga3
+ Revision: 394089
- Refactor the spec a bit

* Sun Jan 13 2013 umeabot <umeabot> 1.8.7-2.mga3
+ Revision: 362671
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 28 2012 sander85 <sander85> 1.8.7-1.mga3
+ Revision: 322726
- New version: 1.8.7

* Thu Aug 30 2012 sander85 <sander85> 1.8.6-1.mga3
+ Revision: 285873
- New version: 1.8.6

* Mon Aug 06 2012 sander85 <sander85> 1.8.5-1.mga3
+ Revision: 279259
- New version: 1.8.5

* Sat Jul 21 2012 sander85 <sander85> 1.8.4-1.mga3
+ Revision: 273115
- clean up systemd hacks, they are not needed anymore
- new version: 1.8.4

* Sat Jun 30 2012 colin <colin> 1.8.3-2.mga3
+ Revision: 265628
- Rebuild for new libudev major

* Fri Jun 15 2012 guillomovitch <guillomovitch> 1.8.3-1.mga3
+ Revision: 260782
- new version
- drop sysinit support
- drop unrecognized configure option

* Sat Apr 28 2012 tmb <tmb> 1.8.2-2.mga2
+ Revision: 233837
- Require rpm-helper >= 0.24.8-1 for systemd support

* Wed Jan 18 2012 sander85 <sander85> 1.8.2-1.mga2
+ Revision: 197970
- new version: 1.8.2

* Sat Jan 14 2012 sander85 <sander85> 1.8.1-5.mga2
+ Revision: 195927
- drop unneeded requires

* Fri Jan 13 2012 sander85 <sander85> 1.8.1-4.mga2
+ Revision: 195797
- move libpcscspy.so into devel

* Fri Jan 13 2012 sander85 <sander85> 1.8.1-3.mga2
+ Revision: 195779
- split libpcscspy into its own package

* Sat Jan 07 2012 sander85 <sander85> 1.8.1-2.mga2
+ Revision: 193014
- better detection of systemd usage
- update description

* Sat Jan 07 2012 sander85 <sander85> 1.8.1-1.mga2
+ Revision: 192976
- fix lsb-comment-block
- new version (1.8.1 with systemd support)

* Sun Jun 26 2011 sander85 <sander85> 1.7.4-2.mga2
+ Revision: 114056
- add some empty directories + fix sources

* Sun Jun 26 2011 sander85 <sander85> 1.7.4-1.mga2
+ Revision: 114051
- add doc + few minor changes
- drop *.la files
- clean spec; nev version: 1.7.4

* Thu Feb 10 2011 spuhler <spuhler> 1.6.6-1.mga1
+ Revision: 49696
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package pcsc-lite


* Sat Jan 01 2011 Anssi Hannula <anssi@mandriva.org> 1.6.6-1mdv2011.0
+ Revision: 627057
- new version
  o deprecated ifdhandler PDF has been dropped

* Mon Aug 16 2010 Emmanuel Andry <eandry@mandriva.org> 1.6.4-1mdv2011.0
+ Revision: 570476
- New version 1.6.4

* Thu Jul 29 2010 Funda Wang <fwang@mandriva.org> 1.6.1-3mdv2011.0
+ Revision: 562991
- add provides for static package

* Thu Jul 29 2010 Funda Wang <fwang@mandriva.org> 1.6.1-2mdv2011.0
+ Revision: 562986
- build static lib for libchipcard

* Thu Jul 29 2010 Funda Wang <fwang@mandriva.org> 1.6.1-1mdv2011.0
+ Revision: 562970
- New version 1.6.1
- use libusb rather than libhal for distro policy

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 1.5.5-2mdv2010.1
+ Revision: 521156
- rebuilt for 2010.1

* Sun Aug 02 2009 Emmanuel Andry <eandry@mandriva.org> 1.5.5-1mdv2010.0
+ Revision: 407552
- New version 1.5.5

* Tue Jul 28 2009 Emmanuel Andry <eandry@mandriva.org> 1.5.4-1mdv2010.0
+ Revision: 402524
- New version 1.5.4

* Fri May 01 2009 Frederik Himpe <fhimpe@mandriva.org> 1.5.3-1mdv2010.0
+ Revision: 370169
- Update to new version 1.5.3

* Sun Feb 15 2009 Frederik Himpe <fhimpe@mandriva.org> 1.5.2-1mdv2009.1
+ Revision: 340647
- Update to new version 1.5.2

* Thu Jan 22 2009 Funda Wang <fwang@mandriva.org> 1.5.1-1mdv2009.1
+ Revision: 332590
- New verison 1.5.1

* Sat Jun 28 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.102-1mdv2009.0
+ Revision: 229708
- 1.4.102
- spec file massage

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 02 2008 Funda Wang <fwang@mandriva.org> 1.4.101-1mdv2009.0
+ Revision: 200030
- New version 1.4.101

* Thu Apr 24 2008 Gustavo De Nardin <gustavodn@mandriva.com> 1.4.100-1mdv2009.0
+ Revision: 197113
- prefers libhal over libusb now
- new version 1.4.100
- update License tag for licensing policy
- better library policy compliance

* Tue Mar 25 2008 Thierry Vignaud <tv@mandriva.org> 1.4.4-3mdv2008.1
+ Revision: 190012
- move 360k of docs into devel subpackage

* Tue Mar 04 2008 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-2mdv2008.1
+ Revision: 179159
- rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - fix description-line-too-long
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Thu Sep 06 2007 Adam Williamson <awilliamson@mandriva.org> 1.4.4-1mdv2008.0
+ Revision: 80711
- correct license to BSD
- new release 1.4.4

* Sat Jul 14 2007 Adam Williamson <awilliamson@mandriva.org> 1.4.3-1mdv2008.0
+ Revision: 52107
- new devel policy
- new release 1.4.3

* Mon May 28 2007 Andreas Hasenack <andreas@mandriva.com> 1.4.2-1mdv2008.0
+ Revision: 32049
- added tetex-latex to buildrequries
- updated to version 1.4.2


* Wed Mar 07 2007 Andreas Hasenack <andreas@mandriva.com> 1.4.0-1mdv2007.0
+ Revision: 134433
- updated to version 1.4.0 (same soname)

* Mon Nov 06 2006 Andreas Hasenack <andreas@mandriva.com> 1.3.2-1mdv2007.1
+ Revision: 77007
- updated to version 1.3.2
- using pid file

* Sat Sep 02 2006 Andreas Hasenack <andreas@mandriva.com> 1.3.1-3mdv2007.0
+ Revision: 59365
- using functions for initscript (#21495)
- updated initscript to use parallel init scheme

  + Helio Chissini de Castro <helio@mandriva.com>
    - New upstream version 1.3.1
    - import pcsc-lite-1.3.0-3mdk

* Tue Apr 18 2006 Andreas Hasenack <andreas@mandriva.com> 1.3.0-3mdk
- added missing provides

* Thu Mar 09 2006 Andreas Hasenack <andreas@mandriva.com> 1.3.0-2mdk
- added missing buildrequires

* Thu Mar 09 2006 Andreas Hasenack <andreas@mandriva.com> 1.3.0-1mdk
- updated to verison 1.3.0, closing #21518
- removed references to libmusclecard, it's a separate package now

* Tue Dec 06 2005 Andreas Hasenack <andreas@mandriva.com> 1.2.9-3mdk
- fixed -devel package conflicts so that it works with x86_64 too
  (thanks to _ranger_ for the tip)

* Thu Nov 24 2005 Andreas Hasenack <andreas@mandriva.com> 1.2.9-2mdk
- versioning devel provides

* Thu Nov 03 2005 Helio Chissini de Castro <heliocastro@mandriva.com> 1.2.9-1mdk
- New upstream beta release

* Tue Jun 14 2005 Frederic Lepied <flepied@mandriva.com> 1.1.2-6mdk
- rebuild

* Thu Oct 28 2004 Frederic Lepied <flepied@mandrakesoft.com> 1.1.2-5mdk
- corrected update-reader-conf to avoid a warning when no config is present
- libification

